updated TODOs.txt
[core.git] / index.php
index 8a0bec3be1dd52b9dad0a75d128df578d7a336de..f0f02f6df124b1ce00ac8d4c18ab96d35d9b7310 100644 (file)
--- a/index.php
+++ b/index.php
@@ -3,12 +3,17 @@
 namespace CoreFramework\EntryPoint;
 
 // Import framework stuff
+use CoreFramework\Bootstrap\FrameworkBootstrap;
 use CoreFramework\Configuration\FrameworkConfiguration;
 use CoreFramework\Factory\ObjectFactory;
 use CoreFramework\Helper\Application\ApplicationHelper;
+use CoreFramework\Localization\LanguageSystem;
 use CoreFramework\Loader\ClassLoader;
 use CoreFramework\Generic\FrameworkException;
 
+// Import SPL stuff
+use \Exception;
+
 /**
  * The main class with the entry point to the whole application. This class
  * "emulates" Java's entry point call. Additionally it covers local
@@ -38,9 +43,9 @@ use CoreFramework\Generic\FrameworkException;
  */
 final class ApplicationEntryPoint {
        /**
-        * Core path
+        * Framework path
         */
-       private static $corePath = '';
+       private static $frameworkPath = '';
 
        /**
         * The application's emergency exit
@@ -52,7 +57,7 @@ final class ApplicationEntryPoint {
         * @return      void
         * @todo        This method is old code and needs heavy rewrite and should be moved to ApplicationHelper
         */
-       public static final function app_exit ($message = '', $code = FALSE, $extraData = '', $silentMode = FALSE) {
+       public static final function app_exit ($message = '', $code = false, $extraData = '', $silentMode = false) {
                // Is this method already called?
                if (isset($GLOBALS['app_die_called'])) {
                        // Then output the text directly
@@ -60,7 +65,7 @@ final class ApplicationEntryPoint {
                } // END - if
 
                // This method shall not be called twice
-               $GLOBALS['app_die_called'] = TRUE;
+               $GLOBALS['app_die_called'] = true;
 
                // Is a message set?
                if (empty($message)) {
@@ -72,13 +77,13 @@ final class ApplicationEntryPoint {
                $configInstance = FrameworkConfiguration::getSelfInstance();
 
                // Do we have debug installation?
-               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === TRUE)) {
+               if (($configInstance->getConfigEntry('product_install_mode') == 'productive') || ($silentMode === true)) {
                        // Abort here
                        exit();
                } // END - if
 
                // Get some instances
-               $tpl = FrameworkConfiguration::getSelfInstance()->getConfigEntry('html_template_class');
+               $tpl = $configInstance->getConfigEntry('html_template_class');
                $languageInstance = LanguageSystem::getSelfInstance();
 
                // Initialize template instance here to avoid warnings in IDE
@@ -94,7 +99,7 @@ final class ApplicationEntryPoint {
                                // Get the template instance from our object factory
                                $templateInstance = ObjectFactory::createObjectByName($tpl);
                        } catch (FrameworkException $e) {
-                               exit(sprintf("[Main:] Could not initialize template engine for reason: <span class=\"exception_reason\">%s</span>",
+                               exit(sprintf('[Main:] Could not initialize template engine for reason: <span class="exception_reason">%s</span>',
                                        $e->getMessage()
                                ));
                        }
@@ -115,7 +120,7 @@ final class ApplicationEntryPoint {
                                } // END - if
 
                                // Add the traceback path to the final output
-                               $backtrace .= sprintf("<span class=\"backtrace_file\">%s</span>:%d, <span class=\"backtrace_function\">%s(%d)</span><br />\n",
+                               $backtrace .= sprintf('<span class="backtrace_file">%s</span>:%d, <span class="backtrace_function">%s(%d)</span><br />' . PHP_EOL,
                                        basename($trace['file']),
                                        $trace['line'],
                                        $trace['function'],
@@ -176,33 +181,33 @@ final class ApplicationEntryPoint {
        }
 
        /**
-        * Determines the correct absolute path for all includes only once per run.
-        * Other calls of this method are being "cached". This is done by checking
-        * a small list of common paths where the framework can reside and check if
-        * inc/config.php can be found.
+        * Determines the correct absolute path for the framework. A set of common
+        * paths is being tested (first most common for applications, second when
+        * core tests are being executed and third/forth if the framework has been
+        * cloned there).
         *
-        * @return      $corePath       Base path (core) for all includes
+        * @return      $frameworkPath  Path for framework
         */
-       protected static final function detectCorePath () {
+       public static final function detectFrameworkPath () {
                // Is it not set?
-               if (empty(self::$corePath)) {
+               if (empty(self::$frameworkPath)) {
                        // Auto-detect core path (first application-common)
-                       foreach (array('core', '.') as $possiblePath) {
+                       foreach (array('core', '.', '/usr/local/share/php/core', '/usr/share/php/core') as $possiblePath) {
                                // Create full path for testing
                                $realPath = realpath($possiblePath);
 
                                // Debug message
                                //* NOISY-DEBUG: */ printf('[%s:%d]: realPath[%s]=%s' . PHP_EOL, __METHOD__, __LINE__, gettype($realPath), $realPath);
 
-                               // Is it FALSE?
-                               if ($realPath === FALSE) {
+                               // Is it false?
+                               if ($realPath === false) {
                                        // Then, not found.
                                        continue;
                                } // END - if
 
// First create full-qualified file name (FQFN) to inc/config.php
                                $fqfn = sprintf(
-                                       '%s%sinc%sconfig.php',
+                                       '%s%sframework%sconfig-global.php',
                                        $realPath,
                                        DIRECTORY_SEPARATOR,
                                        DIRECTORY_SEPARATOR,
@@ -215,16 +220,32 @@ final class ApplicationEntryPoint {
                                // Is it readable?
                                if (is_readable($fqfn)) {
                                        // Found one
-                                       self::$corePath = $realPath;
+                                       self::$frameworkPath = $realPath . '/framework/';
 
                                        // Abort here
                                        break;
                                } // END - if
                        } // END - foreach
+
+                       // Able to find?
+                       if (!is_dir(self::$frameworkPath)) {
+                               // Is no directory
+                               throw new Exception('Cannot find framework.');
+                       } // END - if
                } // END - if
 
                // Return it
-               return self::$corePath;
+               return self::$frameworkPath;
+       }
+
+       /**
+        * Getter for root path
+        *
+        * @return      $rootPath       Root path
+        */
+       public static function getRootPath () {
+               // Get __DIR__, really simple and no detection
+               return __DIR__;
        }
 
        /**
@@ -236,30 +257,31 @@ final class ApplicationEntryPoint {
         * @return      void
         */
        public static final function main () {
-               // Load config file, this provides $cfg
-               require(self::detectCorePath() . '/inc/config.php');
-
-               // Get a new configuration instance
-               $cfg = FrameworkConfiguration::getSelfInstance();
-
-               // Load bootstrap class
-               require($cfg->getConfigEntry('base_path') . 'inc/bootstrap/class_BootstrapFramework.php');
-
-               // ----- Below is deprecated -----
-
-               // Load all include files
-               require($cfg->getConfigEntry('base_path') . 'inc/includes.php');
-
-               // Include the application selector
-               require($cfg->getConfigEntry('base_path') . 'inc/selector.php');
+               // Load bootstrap file
+               require sprintf('%sbootstrap%sbootstrap.inc.php', self::detectFrameworkPath(), DIRECTORY_SEPARATOR);
+
+               /*
+                * Initial bootstrap is done, continue with initialization of
+                * framework.
+                */
+               FrameworkBootstrap::initFramework();
+
+               // Next initialize the detected application
+               FrameworkBootstrap::prepareApplication();
+
+               /*
+                * Last step is to start the application, this will also initialize and
+                * register the application instance in registry.
+                */
+               FrameworkBootstrap::startApplication();
        }
 }
 
 // Developer mode active? Comment out if no dev!
-define('DEVELOPER', TRUE);
+define('DEVELOPER', true);
 
 // Log all exceptions (only debug! This option can create large error logs)
-//define('LOG_EXCEPTIONS', TRUE);
+//define('LOG_EXCEPTIONS', true);
 
 //xdebug_start_trace();
@@ -176,33 +181,33 @@ final class ApplicationEntryPoint {
                                } // END - if
 
-                               // First create full-qualified file name (FQFN) to inc/config.php
+                               // First create full-qualified file name (FQFN) to framework/config-global.php
                                $fqfn = sprintf(